KinAIGradientAnimation enum

Animation behaviour for the gradient.

Inheritance
Available extensions

Values

breathe → const KinAIGradientAnimation

Colours slowly breathe and shift.

orbit → const KinAIGradientAnimation

Fluid blobs orbit and merge.

wave → const KinAIGradientAnimation

Gentle wave ripple across the surface.

shimmer → const KinAIGradientAnimation

Idle shimmer — minimal movement, elegant glow.

pulse → const KinAIGradientAnimation

Energetic pulse — reactive, fast.

none → const KinAIGradientAnimation

No animation — static gradient.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KinAIGradientAnimation>
A constant List of the values in this enum, in order of their declaration.