KinChart class

Inheritance

Constructors

KinChart({Key? key, List<KinChartEntry> entries = const [], List<KinChartSeries>? series, KinChartType type = KinChartType.bar, double? height, bool showLabels = true, bool showValues = false, bool animate = true, KinChartGridStyle gridStyle = const KinChartGridStyle(), KinChartAxisStyle axisStyle = const KinChartAxisStyle(), KinChartLegendPosition legendPosition = KinChartLegendPosition.none, KinChartLineStyle lineStyle = KinChartLineStyle.sharp, double barSpacing = KinSpacing.xs, double barRadius = KinRadius.pill, double donutWidth = 28.0, Widget? donutCenter, Gradient? barGradient, double? minValue, double? maxValue, ValueChanged<KinChartTooltipData>? onEntryTap, Widget tooltipBuilder(KinChartTooltipData data)?, Duration tooltipDuration = const Duration(seconds: 2)})
const
KinChart.area({Key? key, required List<KinChartEntry> entries, List<KinChartSeries>? series, double? height, bool showLabels = true, bool showValues = false, bool animate = true, KinChartGridStyle gridStyle = const KinChartGridStyle(), KinChartAxisStyle axisStyle = const KinChartAxisStyle(), KinChartLegendPosition legendPosition = KinChartLegendPosition.none, KinChartLineStyle lineStyle = KinChartLineStyle.smooth, double? minValue, double? maxValue, ValueChanged<KinChartTooltipData>? onEntryTap, Widget tooltipBuilder(KinChartTooltipData data)?, Duration tooltipDuration = const Duration(seconds: 2)})
const
KinChart.bar({Key? key, required List<KinChartEntry> entries, List<KinChartSeries>? series, double? height, bool showLabels = true, bool showValues = false, bool animate = true, KinChartGridStyle gridStyle = const KinChartGridStyle(), KinChartAxisStyle axisStyle = const KinChartAxisStyle(), KinChartLegendPosition legendPosition = KinChartLegendPosition.none, double barSpacing = KinSpacing.xs, double barRadius = KinRadius.pill, Gradient? barGradient, double? minValue, double? maxValue, ValueChanged<KinChartTooltipData>? onEntryTap, Widget tooltipBuilder(KinChartTooltipData data)?, Duration tooltipDuration = const Duration(seconds: 2)})
const
KinChart.donut({Key? key, required List<KinChartEntry> entries, double? height, bool showLabels = true, bool showValues = false, bool animate = true, KinChartLegendPosition legendPosition = KinChartLegendPosition.bottom, double donutWidth = 28.0, Widget? donutCenter, ValueChanged<KinChartTooltipData>? onEntryTap, Widget tooltipBuilder(KinChartTooltipData data)?, Duration tooltipDuration = const Duration(seconds: 2)})
const
KinChart.horizontalBar({Key? key, required List<KinChartEntry> entries, List<KinChartSeries>? series, double? height, bool showLabels = true, bool showValues = true, bool animate = true, KinChartGridStyle gridStyle = const KinChartGridStyle(showHorizontalLines: false, showVerticalLines: true), KinChartAxisStyle axisStyle = const KinChartAxisStyle(showYAxisLabels: true), KinChartLegendPosition legendPosition = KinChartLegendPosition.none, double barSpacing = KinSpacing.xs, double barRadius = KinRadius.pill, Gradient? barGradient, double? minValue, double? maxValue, ValueChanged<KinChartTooltipData>? onEntryTap, Widget tooltipBuilder(KinChartTooltipData data)?, Duration tooltipDuration = const Duration(seconds: 2)})
const
KinChart.line({Key? key, required List<KinChartEntry> entries, List<KinChartSeries>? series, double? height, bool showLabels = true, bool showValues = false, bool animate = true, KinChartGridStyle gridStyle = const KinChartGridStyle(), KinChartAxisStyle axisStyle = const KinChartAxisStyle(), KinChartLegendPosition legendPosition = KinChartLegendPosition.none, KinChartLineStyle lineStyle = KinChartLineStyle.smooth, double? minValue, double? maxValue, ValueChanged<KinChartTooltipData>? onEntryTap, Widget tooltipBuilder(KinChartTooltipData data)?, Duration tooltipDuration = const Duration(seconds: 2)})
const
KinChart.pie({Key? key, required List<KinChartEntry> entries, double? height, bool showLabels = true, bool showValues = false, bool animate = true, KinChartLegendPosition legendPosition = KinChartLegendPosition.bottom, ValueChanged<KinChartTooltipData>? onEntryTap, Widget tooltipBuilder(KinChartTooltipData data)?, Duration tooltipDuration = const Duration(seconds: 2)})
const

Properties

animate bool
final
axisStyle KinChartAxisStyle
final
barGradient Gradient?
final
barRadius double
final
barSpacing double
final
donutCenter Widget?
final
donutWidth double
final
entries List<KinChartEntry>
final
gridStyle KinChartGridStyle
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
legendPosition KinChartLegendPosition
final
lineStyle KinChartLineStyle
final
maxValue double?
final
minValue double?
final
onEntryTap ValueChanged<KinChartTooltipData>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series List<KinChartSeries>?
final
showLabels bool
final
showValues bool
final
tooltipBuilder Widget Function(KinChartTooltipData data)?
final
tooltipDuration Duration
final
type KinChartType
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited