KinChartAxisStyle class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showXAxisLabels → bool
-
final
- showYAxisLabels → bool
-
final
- xLabelFormatter → String Function(String label)?
-
final
- yAxisWidth → double
-
final
- yLabelFormatter → String Function(double value)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited