KinChartGridStyle class

Constructors

KinChartGridStyle({bool showHorizontalLines = true, bool showVerticalLines = false, int horizontalLineCount = 4, double lineWidth = 0.5, bool dashed = false})
const

Properties

dashed bool
final
hashCode int
The hash code for this object.
no setterinherited
horizontalLineCount int
final
lineWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showHorizontalLines bool
final
showVerticalLines bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

none → const KinChartGridStyle