KinChartTooltipData class

Constructors

KinChartTooltipData({required String label, required double value, required Color color, String? seriesName, required int index, double? percentage})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
label String
final
percentage double?
Percentage of total — only set for pie/donut charts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesName String?
final
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited