KinDataColumn class
Column definition for KinDataTable.
Constructors
Properties
- alignment → Alignment
-
final
- flex → int
-
Flex factor when width is null. Defaults to 1.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortable → bool
-
final
- width → double?
-
Fixed width. If null the column flexes to fill available space.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited