KinDataRow class

Row definition for KinDataTable.

Constructors

KinDataRow({required List<KinDataCell> cells, VoidCallback? onTap, bool selected = false})
const

Properties

cells List<KinDataCell>
final
hashCode int
The hash code for this object.
no setterinherited
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited