KinDropdownMenu<T> class

A themed dropdown menu with spring animation and blur backdrop.

Tapping the trigger opens an overlay dropdown aligned below (or above) that matches the Kin design system.

Inheritance

Constructors

KinDropdownMenu({Key? key, T? value, required List<KinDropdownItem<T>> items, required ValueChanged<T> onChanged, String? hint, String? label, bool enabled = true, Widget itemBuilder(KinDropdownItem<T>)?})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
hint String?
final
itemBuilder Widget Function(KinDropdownItem<T>)?
final
items List<KinDropdownItem<T>>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onChanged ValueChanged<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KinDropdownMenu<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited