KinBentoItem class

Defines a child's span in a KinGridView.bento layout.

Constructors

KinBentoItem({required Widget child, int colSpan = 1, int rowSpan = 1})
const

Properties

child Widget
final
colSpan int
How many columns this item spans.
final
hashCode int
The hash code for this object.
no setterinherited
rowSpan int
How many rows this item spans.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited