KinHeatmapColorScale class

Configuration for heatmap color mapping.

Constructors

KinHeatmapColorScale({required Color emptyColor, required List<Color> gradient})
const

Properties

emptyColor Color
final
gradient List<Color>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

colorFor(double value) Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited