KinPageTransition enum

Visual transition modes for page changes.

Inheritance
Available extensions

Values

slide → const KinPageTransition

Default horizontal slide.

fade → const KinPageTransition

Scale + fade between pages.

parallax → const KinPageTransition

Parallax depth effect.

stack → const KinPageTransition

Stacked card with depth.

zoom → const KinPageTransition

iOS 18 zoom — pages scale in/out with opacity.

cube → const KinPageTransition

3D cube rotation around the Y axis.

flip → const KinPageTransition

Horizontal flip (card flip effect).

depth → const KinPageTransition

Fluid iOS 18 depth — incoming page rises from behind with scale + blur feel.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KinPageTransition>
A constant List of the values in this enum, in order of their declaration.