KinPageView class

A highly customizable page view with transition effects, indicators, and flexible configuration.

Inheritance

Constructors

KinPageView({Key? key, required List<Widget> children, KinPageTransition transition = KinPageTransition.slide, KinPageIndicator indicator = KinPageIndicator.dot, int initialPage = 0, bool enableLoop = false, Axis scrollDirection = Axis.horizontal, ScrollPhysics? physics, double? height, bool pageSnapping = true, ValueChanged<int>? onPageChanged, EdgeInsetsGeometry? padding})
const
KinPageView.parallax({Key? key, required List<Widget> children, KinPageIndicator indicator = KinPageIndicator.dash, int initialPage = 0, bool enableLoop = false, Axis scrollDirection = Axis.horizontal, ScrollPhysics? physics, double? height, bool pageSnapping = true, ValueChanged<int>? onPageChanged, EdgeInsetsGeometry? padding})
Convenience for parallax pages.
const
KinPageView.stack({Key? key, required List<Widget> children, KinPageIndicator indicator = KinPageIndicator.dot, int initialPage = 0, bool enableLoop = false, Axis scrollDirection = Axis.horizontal, ScrollPhysics? physics, double? height, bool pageSnapping = true, ValueChanged<int>? onPageChanged, EdgeInsetsGeometry? padding})
Convenience for stacked card pages.
const

Properties

children List<Widget>
final
enableLoop bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
indicator KinPageIndicator
final
initialPage int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPageChanged ValueChanged<int>?
final
padding EdgeInsetsGeometry?
final
pageSnapping bool
final
physics ScrollPhysics?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection Axis
final
transition KinPageTransition
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KinPageView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited