KinPopupMenu class
A non-material themed popup menu with frosted glass in dark mode.
Items float in a rounded card anchored to the trigger widget. Supports grouped sections via KinPopupMenuDivider.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- KinPopupMenu
Constructors
-
KinPopupMenu({Key? key, required List<
KinPopupMenuItem> items, required Widget child, Alignment alignment = Alignment.topRight, Offset offset = Offset.zero}) -
const
Properties
- alignment → Alignment
-
final
- child → Widget
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
KinPopupMenuItem> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- offset → Offset
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
show(
{required BuildContext context, required List< KinPopupMenuItem> items, required RelativeRect position}) → Future<void> -
Shows the popup anchored relative to
anchorContext.