KinPopupMenuDivider class

A divider that can be placed between KinPopupMenuItems.

Inheritance

Constructors

KinPopupMenuDivider()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDestructive bool
finalinherited
label String
finalinherited
leading Widget?
finalinherited
onTap VoidCallback?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trailing Widget?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited