KinRatingPicker class
A bottom-dialog rating picker with animated icons and optional feedback text.
final rating = await KinRatingPicker.show(context: context);
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- KinRatingPicker
Constructors
-
KinRatingPicker({Key? key, int maxRating = 5, int initialRating = 0, KinRatingStyle style = KinRatingStyle.star, String title = 'Rate', List<
String> ? ratingLabels, ValueChanged<int> ? onConfirm, VoidCallback? onCancel, bool showLabel = true, Color? activeColor, String confirmLabel = 'Submit', String cancelLabel = 'Cancel'}) -
const
Properties
- activeColor → Color?
-
final
- cancelLabel → String
-
final
- confirmLabel → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialRating → int
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxRating → int
-
final
- onCancel → VoidCallback?
-
final
-
onConfirm
→ ValueChanged<
int> ? -
final
-
ratingLabels
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLabel → bool
-
final
- style → KinRatingStyle
-
final
- title → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< KinRatingPicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited