KinStepperVariant enum
Visual style variants for KinStepper.
Values
- numbered → const KinStepperVariant
-
Numbered circles with connecting line.
- dot → const KinStepperVariant
-
Dots expanding on active step.
- progress → const KinStepperVariant
-
Progress bar style with labeled steps.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KinStepperVariant> - A constant List of the values in this enum, in order of their declaration.