KinTimePicker class

Scroll-wheel time picker with iOS 18 fluid spring animations.

Inheritance

Constructors

KinTimePicker({Key? key, required TimeOfDay initialTime, bool use24HourFormat = false, ValueChanged<TimeOfDay>? onConfirm, VoidCallback? onCancel, String title = 'Select Time', String confirmLabel = 'Confirm', String cancelLabel = 'Cancel'})
const

Properties

cancelLabel String
final
confirmLabel String
final
hashCode int
The hash code for this object.
no setterinherited
initialTime TimeOfDay
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCancel VoidCallback?
final
onConfirm ValueChanged<TimeOfDay>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
use24HourFormat bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KinTimePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, TimeOfDay? initialTime, bool use24HourFormat = false, String title = 'Select Time', String confirmLabel = 'Confirm', String cancelLabel = 'Cancel'}) Future<TimeOfDay?>