KinTimelineItem class

A single timeline entry.

Constructors

KinTimelineItem({required String title, String? subtitle, Widget? leading, IconData? icon, Color? color, bool isCompleted = false})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
isCompleted bool
final
leading Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited