KinGlassThickness enum

Thickness presets for glass material — mirrors Apple's SwiftUI materials.

Inheritance
Available extensions

Values

ultraThin → const KinGlassThickness

Very subtle blur, highly transparent.

thin → const KinGlassThickness

Light frosted glass.

regular → const KinGlassThickness

Standard frosted glass (default).

thick → const KinGlassThickness

Heavy frosted glass, less transparency.

ultraThick → const KinGlassThickness

Nearly opaque frosted surface.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KinGlassThickness>
A constant List of the values in this enum, in order of their declaration.