KinTheme class

Eight-color theme extension that every Kin component reads from context.

Inheritance

Constructors

KinTheme({required Color primary, required Color primaryContainer, required Color surface, required Color surfaceVariant, required Color onSurface, required Color onSurfaceVariant, required Color outline, required Color destructive, Color success = const Color(0xFF34C759), Color warning = const Color(0xFFFF9F0A)})
const

Properties

destructive Color
final
hashCode int
The hash code for this object.
no setterinherited
onSurface Color
final
onSurfaceVariant Color
final
outline Color
final
primary Color
final
primaryContainer Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success Color
final
surface Color
final
surfaceVariant Color
final
type Object
The extension's type.
no setterinherited
warning Color
final

Methods

copyWith({Color? primary, Color? primaryContainer, Color? surface, Color? surfaceVariant, Color? onSurface, Color? onSurfaceVariant, Color? outline, Color? destructive, Color? success, Color? warning}) KinTheme
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant KinTheme? other, double t) KinTheme
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

black KinTheme
no setter
dark KinTheme
Default shipped dark preset.
no setter
inkDark KinTheme
Monochrome dark preset tuned for out-of-the-box package usage.
no setter
inkLight KinTheme
Monochrome light preset tuned for out-of-the-box package usage.
no setter
light KinTheme
Default shipped light preset.
no setter
white KinTheme
no setter

Static Methods

of(BuildContext context) KinTheme