KinNavItem class

Icon and label pair for navigation destinations.

Constructors

KinNavItem({required IconData icon, required String label, IconData? activeIcon})
const

Properties

activeIcon IconData?
Optional icon shown when this item is selected.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
The icon displayed in the navigation item.
final
label String
The text label displayed below the icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited