transitions/transitions library
Classes
-
KinPageRoute<
T> - A physics-based page route that combines morphing scale, spring bounce, and elastic motion into a single premium transition.
Enums
- KinTransitionOrigin
- Where the incoming page originates from.