KinBottomBar class

A pill-shaped icon tab bar with iOS 18-style fluid sliding pill.

The glass selector pill physically slides from the previous tab to the tapped tab using spring physics. The selected icon gets a subtle bounce, and the pill smoothly widens at the destination.

Inheritance

Constructors

KinBottomBar({Key? key, int initialIndex = 0, ValueChanged<int>? onTabChanged, Color? selectedIconColor, Color? unselectedIconColor, Color? selectedLabelColor, Color? unselectedLabelColor, double iconSize = 24, double height = 62, double borderRadius = 32, double barBlurSigma = 10, double selectorBlurSigma = 6, List<Widget>? items, List<String>? labels, TextStyle? labelStyle})
const

Properties

barBlurSigma double
final
borderRadius double
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
iconSize double
final
initialIndex int
final
items List<Widget>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labels List<String>?
final
labelStyle TextStyle?
final
onTabChanged ValueChanged<int>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIconColor Color?
final
selectedLabelColor Color?
final
selectorBlurSigma double
final
unselectedIconColor Color?
final
unselectedLabelColor Color?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KinBottomBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited