KinCarousel class
A highly customizable carousel with iOS 18-style fluid spring animations.
Pages transition with subtle 3D parallax, spring-based scale effects, and smoothly morphing indicators.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- KinCarousel
Constructors
-
KinCarousel({Key? key, required List<
Widget> children, KinCarouselVariant variant = KinCarouselVariant.fullBleed, KinCarouselIndicator indicator = KinCarouselIndicator.dot, bool autoPlay = false, Duration autoPlayInterval = const Duration(seconds: 4), double viewportFraction = 0.92, double itemSpacing = KinSpacing.sm, double? height, int initialPage = 0, bool enableLoop = false, bool padEnds = true, EdgeInsetsGeometry contentPadding = EdgeInsets.zero, ValueChanged<int> ? onPageChanged, Axis scrollDirection = Axis.horizontal}) -
const
-
KinCarousel.card({Key? key, required List<
Widget> children, KinCarouselIndicator indicator = KinCarouselIndicator.dot, bool autoPlay = false, Duration autoPlayInterval = const Duration(seconds: 4), double? height, int initialPage = 0, bool enableLoop = false, EdgeInsetsGeometry contentPadding = EdgeInsets.zero, ValueChanged<int> ? onPageChanged, Axis scrollDirection = Axis.horizontal}) -
const
-
KinCarousel.stacked({Key? key, required List<
Widget> children, KinCarouselIndicator indicator = KinCarouselIndicator.dash, bool autoPlay = false, Duration autoPlayInterval = const Duration(seconds: 4), double? height, int initialPage = 0, bool enableLoop = false, EdgeInsetsGeometry contentPadding = EdgeInsets.zero, ValueChanged<int> ? onPageChanged, Axis scrollDirection = Axis.horizontal}) -
const
Properties
- autoPlay → bool
-
final
- autoPlayInterval → Duration
-
final
-
children
→ List<
Widget> -
final
- contentPadding → EdgeInsetsGeometry
-
final
- enableLoop → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- indicator → KinCarouselIndicator
-
final
- initialPage → int
-
final
- itemSpacing → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onPageChanged
→ ValueChanged<
int> ? -
final
- padEnds → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollDirection → Axis
-
final
- variant → KinCarouselVariant
-
final
- viewportFraction → double
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< KinCarousel> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited