KinChartSeries class
Constructors
-
KinChartSeries({required String name, required List<
KinChartEntry> entries, Color? color, Gradient? gradient, KinChartLineStyle lineStyle = KinChartLineStyle.smooth, double strokeWidth = 2.0, bool showDots = true, double dotRadius = 3.5, bool showArea = false}) -
const
Properties
- color → Color?
-
final
- dotRadius → double
-
final
-
entries
→ List<
KinChartEntry> -
final
- gradient → Gradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineStyle → KinChartLineStyle
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showArea → bool
-
final
- showDots → bool
-
final
- strokeWidth → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited