KinLayoutData class
Immutable snapshot of the current layout tier, column count, and margins.
Constructors
- KinLayoutData({required LayoutType type, required int columns, required EdgeInsets margins})
-
const
- KinLayoutData.fromWidth(double width)
-
Uses the shortest side of the available size so that rotating
to landscape keeps the same layout tier (compact stays compact).
factory
Properties
- columns → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCompact → bool
-
no setter
- isExpanded → bool
-
no setter
- isMedium → bool
-
no setter
- margins → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → LayoutType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited