KinMaterial class
Configuration for KinMaterialType.glass and KinMaterialType.tinted.
Constructors
- KinMaterial.glass({KinGlassThickness thickness = KinGlassThickness.regular})
-
const
- KinMaterial.opaque()
-
const
- KinMaterial.tinted({Color? tintColor, double tintOpacity = 0.12})
-
const
Properties
- blurSigma → double
-
Blur sigma for the given thickness.
no setter
- glassBorderOpacity → double
-
Border opacity for the glass edge highlight.
no setter
- glassFillOpacityDark → double
-
Fill opacity for the glass surface (dark mode).
no setter
- glassFillOpacityLight → double
-
Fill opacity for the glass surface (light mode).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thickness → KinGlassThickness
-
Glass thickness — only used when type is KinMaterialType.glass.
final
- tintColor → Color?
-
Tint color — only used when type is KinMaterialType.tinted.
Defaults to the theme's primary color.
final
- tintOpacity → double
-
Tint opacity (0.0 – 1.0) for tinted surfaces.
final
- type → KinMaterialType
-
The material appearance type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultMaterial → const KinMaterial
- Default opaque material.