Corner-radius constants and pre-built BorderRadius values.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lg → const double
- lgAll → const BorderRadius
- md → const double
- mdAll → const BorderRadius
- pill → const double
- pillAll → const BorderRadius
- sm → const double
- smAll → const BorderRadius
- xl → const double
- xlAll → const BorderRadius